@@ -24,6 +24,86 @@ if "DEBUG_BOTO" not in os.environ:
     logging.getLogger("s3transfer").setLevel(logging.CRITICAL)
 
 
+class MetaBucket:
+    """
+    Parent class of Bucket, to include classmethods in docs.
+
+    Note:
+        This class should not be used & instead methods should b
+        called via the Bucket class.
+    """
+
+    def config(
+        cls, access_key: str, secret_key: str, endpoint: str = None, region: str = ""
+    ) -> NoReturn:
+        """
+        Config the bucket connection parameters before init.
+
+        Args:
+            access_key (str): AWS_ACCESS_KEY_ID.
+            secret_key (str): AWS_SECRET_ACCESS_KEY.
+            endpoint (str): Endpoint for the S3, if not AWS.
+                Defaults to None.
+            region (str): AWS_REGION.
+                Defaults to empty string "".
+
+        Note:
+            This method should not be required, as __init__ handles config parameters.
+            It can be used to reconfigure the endpoint and credentials, prior to init.
+            Usage: Bucket.config(**args), then new_bucket = Bucket(<bucket_name>)
+        """
+        cls._AWS_ACCESS_KEY_ID = access_key
+        cls._AWS_SECRET_ACCESS_KEY = secret_key
+        cls._AWS_ENDPOINT = endpoint
+        cls._AWS_REGION = region
+
+    def get_boto3_resource() -> NoReturn:
+        """
+        Get boto3 resource object directly, for further use.
+
+        Note:
+            Usage: Bucket.get_boto3_resource()
+        """
+        log.debug("Accessing boto3 resource.")
+        return boto3.resource(
+            "s3",
+            aws_access_key_id=Bucket._AWS_ACCESS_KEY_ID,
+            aws_secret_access_key=Bucket._AWS_SECRET_ACCESS_KEY,
+            endpoint_url=Bucket._AWS_ENDPOINT,
+            region_name=Bucket._AWS_REGION,
+            config=Config(signature_version="s3v4"),
+        )
+
+    def get_boto3_client() -> NoReturn:
+        """
+        Get boto3 client object directly, for further use.
+
+        Note:
+            Usage: Bucket.get_boto3_client()
+        """
+        log.debug("Accessing boto3 client.")
+        return boto3.client(
+            "s3",
+            aws_access_key_id=Bucket._AWS_ACCESS_KEY_ID,
+            aws_secret_access_key=Bucket._AWS_SECRET_ACCESS_KEY,
+            endpoint_url=Bucket._AWS_ENDPOINT,
+            region_name=Bucket._AWS_REGION,
+            config=Config(signature_version="s3v4"),
+        )
+
+    def list_buckets(cls) -> list[str]:
+        """
+        Get a list of all buckets from endpoint.
+
+        Note:
+            Usage: Bucket.list_buckets()
+        """
+        resource = cls.get_boto3_resource()
+        buckets = [bucket.name for bucket in resource.buckets.all()]
+        log.info(f"All buckets at {Bucket._AWS_ENDPOINT}: {buckets}")
+        return buckets
+
+
 class Bucket:
     """Class to handle S3 bucket transactions.
 
@@ -35,6 +115,12 @@ class Bucket:
     _AWS_ENDPOINT = os.getenv("AWS_ENDPOINT")
     _AWS_REGION = os.getenv("AWS_REGION", default="")
 
+    # Set class & staticmethods from MetaBucket
+    config = classmethod(MetaBucket.config)
+    get_boto3_resource = staticmethod(MetaBucket.get_boto3_resource)
+    get_boto3_client = staticmethod(MetaBucket.get_boto3_client)
+    list_buckets = classmethod(MetaBucket.list_buckets)
+
     def __init__(
         self,
         bucket_name: str = None,
@@ -91,67 +177,6 @@ class Bucket:
         if is_new:
             self.create()
 
-    @classmethod
-    def config(
-        cls, access_key: str, secret_key: str, endpoint: str = None, region: str = ""
-    ) -> NoReturn:
-        """Config the bucket connection parameters before init.
-
-        Args:
-            access_key (str): AWS_ACCESS_KEY_ID.
-            secret_key (str): AWS_SECRET_ACCESS_KEY.
-            endpoint (str): Endpoint for the S3, if not AWS.
-                Defaults to None.
-            region (str): AWS_REGION.
-                Defaults to empty string "".
-        """
-        cls._AWS_ACCESS_KEY_ID = access_key
-        cls._AWS_SECRET_ACCESS_KEY = secret_key
-        cls._AWS_ENDPOINT = endpoint
-        cls._AWS_REGION = region
-
-    @staticmethod
-    def get_boto3_resource() -> NoReturn:
-        """Configure boto3 resource object."""
-        log.debug("Accessing boto3 resource.")
-        return boto3.resource(
-            "s3",
-            aws_access_key_id=Bucket._AWS_ACCESS_KEY_ID,
-            aws_secret_access_key=Bucket._AWS_SECRET_ACCESS_KEY,
-            endpoint_url=Bucket._AWS_ENDPOINT,
-            region_name=Bucket._AWS_REGION,
-            config=Config(signature_version="s3v4"),
-        )
-
-    @staticmethod
-    def get_boto3_client() -> NoReturn:
-        """Cofigure boto3 client object."""
-        log.debug("Accessing boto3 client.")
-        return boto3.client(
-            "s3",
-            aws_access_key_id=Bucket._AWS_ACCESS_KEY_ID,
-            aws_secret_access_key=Bucket._AWS_SECRET_ACCESS_KEY,
-            endpoint_url=Bucket._AWS_ENDPOINT,
-            region_name=Bucket._AWS_REGION,
-            config=Config(signature_version="s3v4"),
-        )
-
-    @staticmethod
-    def list_buckets() -> list[str]:
-        """Get a list of all buckets from endpoint."""
-        log.debug("Accessing boto3 resource.")
-        resource = boto3.resource(
-            "s3",
-            aws_access_key_id=Bucket._AWS_ACCESS_KEY_ID,
-            aws_secret_access_key=Bucket._AWS_SECRET_ACCESS_KEY,
-            endpoint_url=Bucket._AWS_ENDPOINT,
-            region_name=Bucket._AWS_REGION,
-            config=Config(signature_version="s3v4"),
-        )
-        buckets = [bucket.name for bucket in resource.buckets.all()]
-        log.info(f"All buckets at {Bucket._AWS_ENDPOINT}: {buckets}")
-        return buckets
-
     def _handle_boto3_client_error(self, e: ClientError, key: str = None) -> NoReturn:
         """Handle boto3 ClientError.
 
@@ -841,6 +866,12 @@ class Bucket:
 
             log.debug(f"Iterating bucket {self.bucket_name} per 1000 entries")
             for page_num, page in enumerate(pages):
+
+                # No files found, skip
+                if page["KeyCount"] < 1:
+                    log.debug("No files found in bucket.")
+                    continue
+
                 log.debug(f"Page number: {page_num}")
                 for obj in page["Contents"]:
                     bucket_size += obj["Size"]
